<no title> — CALCEPH - Fortran 2003 language 3.4.1 documentation

It is designed to work with Matlab or Octave software.

With Octave, you should load this package :

    pkg load calcephoct

If you want Octave to automatically load this package, simply add to the file octaverc the command pkg load calcephoct .

With Matlab, you should add the path to the Matlab files of the dynamic library CALCEPH :

    addpath('<prefix>/libexec/calceph/mex/')

By default, this prefix is /usr/local, so you have to enter before using calceph library.

    addpath('/usr/local/libexec/calceph/mex/')

If you want Matlab to automatically add this path at startup, simply add to this path to the environment variable MATLABPATH.

Relative to C or Fortran interface, the prefixes calceph_, CALCEPH_, NAIFID_ are deleted for the naming convention of the functions, constants and NAIF identification numbers.